@@ -8,13 +8,18 @@ from .Zip import Zip
 
 def deploy(config):
     bucket_name = os.environ["LAMBDA_CODE_BUCKET"]
-    code_zip = Zip(name=config["FUNCTION_NAME"],path=config["CODE_DIR"]).name
     function = LambdaFunction(config["FUNCTION_NAME"])
-    code_bucket = S3Bucket(bucket_name)
-    code_bucket.upload_file(code_zip)
+    if "LAMBDA_IMAGE" in config:
+        function.deploy_image(config["LAMBDA_IMAGE"])
+    else:
+        code_zip = Zip(name=config["FUNCTION_NAME"],path=config["CODE_DIR"]).name
+        code_bucket = S3Bucket(bucket_name)
+        code_bucket.upload_file(code_zip)
+        function.deploy_zip(bucket_name,code_zip)
+   
     variables = get_variables(config)
-    function.deploy(bucket_name,code_zip)
     function.update_env_variables(variables)
+
     version = function.publish_version(config["VERSION"])["Version"]
     function.update_alias(alias="stable",description=config["VERSION"],version=version)
 
